@@ -2,14 +2,17 @@ from mq_consumer.connectors import Connector
 
 
 class MQChecker:
-    def __init__(self, connector: Connector, passive=True):
+    def __init__(self, connector: Connector, passive=True, durable=False):
         self.connector = connector
         self.passive = passive
+        self.durable = durable
 
     def get_message_count(self):
         self.connector.create_connection(declare=False)
         try:
-            msg_count = self.connector.channel.queue_declare(queue=self.connector.queue, passive=self.passive).method.message_count
+            msg_count = self.connector.channel.queue_declare(
+                queue=self.connector.queue, passive=self.passive, durable=self.durable
+            ).method.message_count
         finally:
             self.connector.close()
         return msg_count
